@@ -1,10 +1,13 @@
 #' @keywords EPA
 #' @export
-#' @title Parse Data from EPA
+#' @import MazamaCoreUtils
+#'
+#' @title Parse EPA data
+#'
 #' @param zipFile absolute path to monitoring data .zip file
 #' @description This function uncompress previously downloaded air quality .zip files from the EPA and
 #' reads it into a tibble.
-#' 
+#'
 #' Available parameters include:
 #' \enumerate{
 #' \item{Ozone}
@@ -14,14 +17,14 @@
 #' \item{PM2.5}
 #' \item{PM10}
 #' \item{Wind}
-#' \item{Temperatue}
+#' \item{Temperature}
 #' \item{Barometric_Pressure}
 #' \item{RH_and_Dewpoint}
 #' \item{HAPs}
 #' \item{VOCs}
 #' \item{NONOxNOy}
 #' }
-#' 
+#'
 #' Associated parameter codes include:
 #' \enumerate{
 #' \item{44201}{ -- Ozone}
@@ -60,42 +63,44 @@
 #   baseUrl='http://aqs.epa.gov/aqsweb/airdata/'
 # }
 
-epa_parseData <- function(zipFile=NULL) {
-  
+epa_parseData <- function(zipFile = NULL) {
+
+  logger.debug(" ----- epa_parseData() ----- ")
+
   # Sanity checks
   if ( is.null(zipFile) ) {
     logger.error("Required parameter 'zipFile' is missing")
     stop(paste0("Required parameter 'zipFile' is missing"))
   }
-  
+
   csvFile <- stringr::str_replace(zipFile,"\\.zip","\\.csv")
-  
+
   # Uncompress
-  logger.debug(paste0('Uncompressing ',zipFile,' ...'))
+  logger.trace(paste0('Uncompressing ',zipFile,' ...'))
   utils::unzip(zipFile, exdir=dirname(zipFile))
-  logger.debug(paste0('Finished uncompressing'))
-  
-  
+  logger.trace(paste0('Finished uncompressing'))
+
+
   # Here are the column names from an EPA hourly dataset:
-  
-  #   [1] "State Code"          "County Code"         "Site Num"            "Parameter Code"      "POC"                
-  #   [6] "Latitude"            "Longitude"           "Datum"               "Parameter Name"      "Date Local"         
-  #   [11] "Time Local"          "Date GMT"            "Time GMT"            "Sample Measurement"  "Units of Measure"   
-  #   [16] "MDL"                 "Uncertainty"         "Qualifier"           "Method Type"         "Method Code"        
+
+  #   [1] "State Code"          "County Code"         "Site Num"            "Parameter Code"      "POC"
+  #   [6] "Latitude"            "Longitude"           "Datum"               "Parameter Name"      "Date Local"
+  #   [11] "Time Local"          "Date GMT"            "Time GMT"            "Sample Measurement"  "Units of Measure"
+  #   [16] "MDL"                 "Uncertainty"         "Qualifier"           "Method Type"         "Method Code"
   #   [21] "Method Name"         "State Name"          "County Name"         "Date of Last Change"
-  
+
   # Assign appropriate data types
   col_types <- paste0("ccccc","ddccc","cccdc","ddccc","cccc")
-  
+
   # Read in the data
-  logger.debug(paste0('Reading in ',csvFile,' ...'))
+  logger.trace(paste0('Reading in ',csvFile,' ...'))
   tbl <- readr::read_csv(csvFile, col_types=col_types)
-  logger.debug(paste0('Finished reading in ',csvFile))
-  
+  logger.trace(paste0('Finished reading in ',csvFile))
+
   # Cleanup
   file.remove(csvFile)
-  
-  logger.debug('Downloaded and parsed %d rows of EPA data', nrow(tbl))
-  
+
+  logger.trace('Downloaded and parsed %d rows of EPA data', nrow(tbl))
+
   return(tbl)
 }
